@@ -247,12 +247,12 @@ gssdp_resource_browser_class_init (GSSDPResourceBrowserClass *klass)
 {
         GObjectClass *object_class;
 
-	object_class = G_OBJECT_CLASS (klass);
+        object_class = G_OBJECT_CLASS (klass);
 
-	object_class->set_property = gssdp_resource_browser_set_property;
-	object_class->get_property = gssdp_resource_browser_get_property;
-	object_class->dispose      = gssdp_resource_browser_dispose;
-	object_class->finalize     = gssdp_resource_browser_finalize;
+        object_class->set_property = gssdp_resource_browser_set_property;
+        object_class->get_property = gssdp_resource_browser_get_property;
+        object_class->dispose      = gssdp_resource_browser_dispose;
+        object_class->finalize     = gssdp_resource_browser_finalize;
 
         g_type_class_add_private (klass, sizeof (GSSDPResourceBrowserPrivate));
 
@@ -390,9 +390,9 @@ gssdp_resource_browser_new (GSSDPClient *client,
                              NULL);
 }
 
-/**
+/*
  * Sets the #GSSDPClient @resource_browser is associated with to @client
- **/
+ */
 static void
 gssdp_resource_browser_set_client (GSSDPResourceBrowser *resource_browser,
                                    GSSDPClient          *client)
@@ -574,9 +574,9 @@ gssdp_resource_browser_get_active (GSSDPResourceBrowser *resource_browser)
         return resource_browser->priv->active;
 }
 
-/**
+/*
  * Resource expired: Remove
- **/
+ */
 static gboolean
 resource_expire (gpointer user_data)
 {
@@ -614,7 +614,6 @@ resource_available (GSSDPResourceBrowser *resource_browser,
         gboolean was_cached;
         guint timeout;
         GList *locations;
-        GMainContext *context;
 
         usn = soup_message_headers_get_one (headers, "USN");
         if (!usn)
@@ -705,13 +704,12 @@ resource_available (GSSDPResourceBrowser *resource_browser,
         }
 
         resource->timeout_src = g_timeout_source_new_seconds (timeout);
-	g_source_set_callback (resource->timeout_src,
+        g_source_set_callback (resource->timeout_src,
                                resource_expire,
-			       resource, NULL);
+                               resource, NULL);
 
-        context = gssdp_client_get_main_context
-                (resource_browser->priv->client);
-	g_source_attach (resource->timeout_src, context);
+        g_source_attach (resource->timeout_src,
+                         g_main_context_get_thread_default ());
 
         g_source_unref (resource->timeout_src);
 
@@ -844,9 +842,9 @@ received_announcement (GSSDPResourceBrowser *resource_browser,
                 resource_unavailable (resource_browser, headers);
 }
 
-/**
+/*
  * Received a message
- **/
+ */
 static void
 message_received_cb (GSSDPClient        *client,
                      const char         *from_ip,
@@ -874,9 +872,9 @@ message_received_cb (GSSDPClient        *client,
         }
 }
 
-/**
+/*
  * Free a Resource structure and its contained data
- **/
+ */
 static void
 resource_free (gpointer data)
 {
@@ -906,9 +904,9 @@ clear_cache_helper (gpointer key, gpointer value, gpointer data)
         return TRUE;
 }
 
-/**
+/*
  * Clears the cached resources hash
- **/
+ */
 static void
 clear_cache (GSSDPResourceBrowser *resource_browser)
 {
@@ -932,7 +930,8 @@ send_discovery_request (GSSDPResourceBrowser *resource_browser)
         _gssdp_client_send_message (resource_browser->priv->client,
                                     NULL,
                                     0,
-                                    message);
+                                    message,
+                                    _GSSDP_DISCOVERY_REQUEST);
 
         g_free (message);
 }
@@ -949,7 +948,7 @@ discovery_timeout (gpointer data)
         resource_browser->priv->num_discovery += 1;
 
         if (resource_browser->priv->num_discovery >= MAX_DISCOVERY_MESSAGES) {
-		resource_browser->priv->timeout_src = NULL;
+                resource_browser->priv->timeout_src = NULL;
                 resource_browser->priv->num_discovery = 0;
 
                 return FALSE;
@@ -961,8 +960,6 @@ discovery_timeout (gpointer data)
 static void
 start_discovery (GSSDPResourceBrowser *resource_browser)
 {
-        GMainContext *context;
-
         /* Send one now */
         send_discovery_request (resource_browser);
 
@@ -970,13 +967,12 @@ start_discovery (GSSDPResourceBrowser *resource_browser)
         resource_browser->priv->num_discovery = 1;
         resource_browser->priv->timeout_src =
                 g_timeout_source_new (DISCOVERY_FREQUENCY);
-	g_source_set_callback (resource_browser->priv->timeout_src,
-			       discovery_timeout,
-			       resource_browser, NULL);
+        g_source_set_callback (resource_browser->priv->timeout_src,
+                               discovery_timeout,
+                               resource_browser, NULL);
 
-        context = gssdp_client_get_main_context
-                (resource_browser->priv->client);
-	g_source_attach (resource_browser->priv->timeout_src, context);
+        g_source_attach (resource_browser->priv->timeout_src,
+                         g_main_context_get_thread_default ());
 
         g_source_unref (resource_browser->priv->timeout_src);
 }
@@ -985,9 +981,9 @@ start_discovery (GSSDPResourceBrowser *resource_browser)
 static void
 stop_discovery (GSSDPResourceBrowser *resource_browser)
 {
-	if (resource_browser->priv->timeout_src) {
-		g_source_destroy (resource_browser->priv->timeout_src);
-		resource_browser->priv->timeout_src = NULL;
-		resource_browser->priv->num_discovery = 0;
-	}
+        if (resource_browser->priv->timeout_src) {
+                g_source_destroy (resource_browser->priv->timeout_src);
+                resource_browser->priv->timeout_src = NULL;
+                resource_browser->priv->num_discovery = 0;
+        }
 }
