@@ -281,11 +281,11 @@ gssdp_resource_group_class_init (GSSDPResourceGroupClass *klass)
 {
         GObjectClass *object_class;
 
-	object_class = G_OBJECT_CLASS (klass);
+        object_class = G_OBJECT_CLASS (klass);
 
-	object_class->set_property = gssdp_resource_group_set_property;
-	object_class->get_property = gssdp_resource_group_get_property;
-	object_class->dispose      = gssdp_resource_group_dispose;
+        object_class->set_property = gssdp_resource_group_set_property;
+        object_class->get_property = gssdp_resource_group_get_property;
+        object_class->dispose      = gssdp_resource_group_dispose;
 
         g_type_class_add_private (klass, sizeof (GSSDPResourceGroupPrivate));
 
@@ -379,9 +379,9 @@ gssdp_resource_group_new (GSSDPClient *client)
                              NULL);
 }
 
-/**
+/*
  * Sets the #GSSDPClient @resource_group is associated with @client
- **/
+ */
 static void
 gssdp_resource_group_set_client (GSSDPResourceGroup *resource_group,
                                  GSSDPClient        *client)
@@ -405,7 +405,7 @@ gssdp_resource_group_set_client (GSSDPResourceGroup *resource_group,
  * gssdp_resource_group_get_client
  * @resource_group: A #GSSDPResourceGroup
  *
- * Return: (transfer none): The #GSSDPClient @resource_group is associated with.
+ * Returns: (transfer none): The #GSSDPClient @resource_group is associated with.
  **/
 GSSDPClient *
 gssdp_resource_group_get_client (GSSDPResourceGroup *resource_group)
@@ -522,7 +522,6 @@ gssdp_resource_group_set_available (GSSDPResourceGroup *resource_group,
         resource_group->priv->available = available;
 
         if (available) {
-                GMainContext *context;
                 int timeout;
 
                 /* We want to re-announce at least 3 times before the resource
@@ -538,13 +537,12 @@ gssdp_resource_group_set_available (GSSDPResourceGroup *resource_group,
                 /* Add re-announcement timer */
                 resource_group->priv->timeout_src =
                         g_timeout_source_new_seconds (timeout);
-		g_source_set_callback (resource_group->priv->timeout_src,
-				       resource_group_timeout,
-				       resource_group, NULL);
+                g_source_set_callback (resource_group->priv->timeout_src,
+                                       resource_group_timeout,
+                                       resource_group, NULL);
 
-                context = gssdp_client_get_main_context
-                        (resource_group->priv->client);
-		g_source_attach (resource_group->priv->timeout_src, context);
+                g_source_attach (resource_group->priv->timeout_src,
+                                 g_main_context_get_thread_default ());
 
                 g_source_unref (resource_group->priv->timeout_src);
 
@@ -710,9 +708,9 @@ gssdp_resource_group_remove_resource (GSSDPResourceGroup *resource_group,
         }
 }
 
-/**
+/*
  * Called to re-announce all resources periodically
- **/
+ */
 static gboolean
 resource_group_timeout (gpointer user_data)
 {
@@ -728,9 +726,9 @@ resource_group_timeout (gpointer user_data)
         return TRUE;
 }
 
-/**
+/*
  * Received a message
- **/
+ */
 static void
 message_received_cb (GSSDPClient        *client,
                      const char         *from_ip,
@@ -805,7 +803,6 @@ message_received_cb (GSSDPClient        *client,
                         /* Match. */
                         guint timeout;
                         DiscoveryResponse *response;
-                        GMainContext *context;
 
                         /* Get a random timeout from the interval [0, mx] */
                         timeout = g_random_int_range (0, mx * 1000);
@@ -824,12 +821,12 @@ message_received_cb (GSSDPClient        *client,
 
                         /* Add timeout */
                         response->timeout_src = g_timeout_source_new (timeout);
-			g_source_set_callback (response->timeout_src,
-					       discovery_response_timeout,
-					       response, NULL);
+                        g_source_set_callback (response->timeout_src,
+                                               discovery_response_timeout,
+                                               response, NULL);
 
-                        context = gssdp_client_get_main_context (client);
-			g_source_attach (response->timeout_src, context);
+                        g_source_attach (response->timeout_src,
+                                         g_main_context_get_thread_default ());
 
                         g_source_unref (response->timeout_src);
                         
@@ -840,9 +837,9 @@ message_received_cb (GSSDPClient        *client,
         }
 }
 
-/**
+/*
  * Construct the AL (Alternative Locations) header for @resource
- **/
+ */
 static char *
 construct_al (Resource *resource)
 {
@@ -866,7 +863,9 @@ construct_al (Resource *resource)
 }
 
 static char *
-construct_usn (const char *usn, const char *response_target, const char *resource_target)
+construct_usn (const char *usn,
+               const char *response_target,
+               const char *resource_target)
 {
         const char *needle;
         char *prefix;
@@ -884,9 +883,9 @@ construct_usn (const char *usn, const char *response_target, const char *resourc
         return st;
 }
 
-/**
+/*
  * Send a discovery response
- **/
+ */
 static gboolean
 discovery_response_timeout (gpointer user_data)
 {
@@ -905,7 +904,9 @@ discovery_response_timeout (gpointer user_data)
         max_age = response->resource->resource_group->priv->max_age;
 
         al = construct_al (response->resource);
-        usn = construct_usn (response->resource->usn, response->target, response->resource->target);
+        usn = construct_usn (response->resource->usn,
+                             response->target,
+                             response->resource->target);
         date = soup_date_new_from_now (0);
         date_str = soup_date_to_string (date, SOUP_DATE_HTTP);
         soup_date_free (date);
@@ -935,9 +936,9 @@ discovery_response_timeout (gpointer user_data)
         return FALSE;
 }
 
-/**
+/*
  * Free a DiscoveryResponse structure and its contained data
- **/
+ */
 static void
 discovery_response_free (DiscoveryResponse *response)
 {
@@ -952,9 +953,9 @@ discovery_response_free (DiscoveryResponse *response)
         g_slice_free (DiscoveryResponse, response);
 }
 
-/**
+/*
  * Send the next queued message, if any
- **/
+ */
 static gboolean
 process_queue (gpointer data)
 {
@@ -986,11 +987,11 @@ process_queue (gpointer data)
         }
 }
 
-/**
+/*
  * Add a message to sending queue
  * 
  * Do not free @message.
- **/
+ */
 static void
 queue_message (GSSDPResourceGroup *resource_group,
                char               *message)
@@ -1001,23 +1002,20 @@ queue_message (GSSDPResourceGroup *resource_group,
         if (resource_group->priv->message_src == NULL) {
                 /* nothing in the queue: process message immediately 
                    and add a timeout for (possible) next message */
-                GMainContext *context;
-
                 process_queue (resource_group);
                 resource_group->priv->message_src = g_timeout_source_new (
                     resource_group->priv->message_delay);
                 g_source_set_callback (resource_group->priv->message_src,
                     process_queue, resource_group, NULL);
-                context = gssdp_client_get_main_context (
-                    resource_group->priv->client);
-                g_source_attach (resource_group->priv->message_src, context);
+                g_source_attach (resource_group->priv->message_src,
+                                 g_main_context_get_thread_default ());
                 g_source_unref (resource_group->priv->message_src);
         }
 }
 
-/**
+/*
  * Send ssdp:alive message for @resource
- **/
+ */
 static void
 resource_alive (Resource *resource)
 {
@@ -1051,9 +1049,9 @@ resource_alive (Resource *resource)
         g_free (al);
 }
 
-/**
+/*
  * Send ssdp:byebye message for @resource
- **/
+ */
 static void
 resource_byebye (Resource *resource)
 {
@@ -1070,9 +1068,9 @@ resource_byebye (Resource *resource)
         }
 }
 
-/**
+/*
  * Free a Resource structure and its contained data
- **/
+ */
 static void
 resource_free (Resource *resource)
 {
